.. black documentation master file, created by
   sphinx-quickstart on Fri Mar 23 10:53:30 2018.

The uncompromising code formatter
=================================

By using *Black*, you agree to cede control over minutiae of
hand-formatting. In return, *Black* gives you speed, determinism, and
freedom from `pycodestyle` nagging about formatting. You will save time
and mental energy for more important matters.

*Black* makes code review faster by producing the smallest diffs
possible. Blackened code looks the same regardless of the project
you're reading. Formatting becomes transparent after a while and you
can focus on the content instead.

Try it out now using the `Black Playground <https://black.now.sh>`_.

.. note::

   `Black is beta <installation_and_usage.html#note-this-is-a-beta-product>`_.


Testimonials
------------

**Dusty Phillips**, `writer <https://smile.amazon.com/s/ref=nb_sb_noss?url=search-alias%3Daps&field-keywords=dusty+phillips>`_:

   *Black is opinionated so you don't have to be.*

**Hynek Schlawack**, creator of `attrs <https://www.attrs.org/>`_, core
developer of Twisted and CPython:

   *An auto-formatter that doesn't suck is all I want for Xmas!*

**Carl Meyer**, `Django <https://www.djangoproject.com/>`_ core developer:

   *At least the name is good.*

**Kenneth Reitz**, creator of `requests <http://python-requests.org/>`_
and `pipenv <https://docs.pipenv.org/>`_:

   *This vastly improves the formatting of our code. Thanks a ton!*

Contents
--------

.. toctree::
   :maxdepth: 2

   installation_and_usage
   the_black_code_style
   pyproject_toml
   editor_integration
   blackd
   version_control_integration
   ignoring_unmodified_files
   contributing
   show_your_style
   change_log
   reference/reference_summary
   authors

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
